Fix autoconf with java home (#284)

* do not use checked in configs if java_home is used

* doc fix
diff --git a/rules/rbe_repo.bzl b/rules/rbe_repo.bzl
index c67307d..448ca99 100644
--- a/rules/rbe_repo.bzl
+++ b/rules/rbe_repo.bzl
@@ -790,9 +790,11 @@
               "please make sure it is declared in " +
               "@bazel_toolchains//rules:toolchain_containers.bzl" % revision))
 
     # If the user has set a custom env, registry or repository don't use
     # checked in configs
     if ((env and env != clang_env()) or
+        (java_home) or
         (registry and registry != _RBE_UBUNTU_REGISTRY) or
         (repository and repository != _RBE_UBUNTU_REPO)):
         use_checked_in_confs = False
@@ -790,9 +790,11 @@
               "@bazel_toolchains//rules:toolchain_containers.bzl" % revision))
 
-    # If the user has set a custom env, registry or repository don't use
+    # If the user has set a custom env, custom java_home,
+    # registry or repository, don't use
     # checked in configs
     if ((env and env != clang_env()) or